package com.example.siamobile

import android.os.Bundle
import androidx.activity.ComponentActivity
import androidx.activity.compose.setContent
import androidx.compose.foundation.background
import androidx.compose.foundation.layout.*
import androidx.compose.foundation.lazy.LazyColumn
import androidx.compose.foundation.lazy.items
import androidx.compose.material3.*
import androidx.compose.runtime.Composable
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.platform.LocalContext
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.unit.dp
import com.example.siamobile.ui.theme.SIAMobileTheme

data class MataKuliah(
    val no: Int,
    val namaMK: String,
    val sem: Int,
)

class Mhs202210715290 : ComponentActivity() {
    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        val mahasiswaName = intent.getStringExtra("mahasiswaName") ?: "Nama: Najwa Mima Salsabila\nNPM: 202210715290"
        setContent {
            SIAMobileTheme {
                DetailMahasiswaScreen2(mahasiswaName)
            }
        }
    }
}

@Composable
fun DetailMahasiswaScreen2(mahasiswaName: String) {
    val context = LocalContext.current

    Column(
        modifier = Modifier
            .fillMaxSize()
            .padding(16.dp),
        verticalArrangement = Arrangement.SpaceBetween
    ) {
        Column {
            Text(
                text = "KHS Mahasiswa",
                style = MaterialTheme.typography.headlineMedium,
                fontWeight = FontWeight.Bold
            )
            Spacer(modifier = Modifier.height(8.dp))
            Text(
                text = mahasiswaName,
                style = MaterialTheme.typography.bodyLarge,
                fontWeight = FontWeight.Medium
            )
            Spacer(modifier = Modifier.height(16.dp))
            TabelMataKuliah() // Menambahkan tabel mata kuliah
        }

        // Remove Spacer and use a fixed height for the button area
        Button(
            onClick = { (context as? ComponentActivity)?.finish() },
            modifier = Modifier
                .align(Alignment.CenterHorizontally)
                .padding(top = 16.dp) // Add some padding for spacing
                .fillMaxWidth() // Make the button full width
        ) {
            Text(text = "Kembali")
        }
    }
}

@Composable
fun TabelMataKuliah() {
    val mataKuliahList = listOf(
        MataKuliah(1, "Bahasa Indonesia", 2),
        MataKuliah(2, "Desain dan Analisis Algoritma", 2),
        MataKuliah(3, "Kalkulus II", 2),
        MataKuliah(4, "Logika Matematika", 2),
        MataKuliah(5, "Matematika Diskrit", 2),
        MataKuliah(6, "Sistem Basis Data", 2)
    )

    Column(modifier = Modifier.fillMaxWidth()) {
        // Header Tabel
        Row(
            modifier = Modifier
                .fillMaxWidth()
                .padding(8.dp)
                .background(Color(0xFFFFC0CB)), // Pink
            verticalAlignment = Alignment.CenterVertically
        ) {
            Text("No", modifier = Modifier.weight(0.1f), fontWeight = FontWeight.Bold, color = Color.White)
            Text("Mata Kuliah", modifier = Modifier.weight(0.4f), fontWeight = FontWeight.Bold, color = Color.White)
            Text("Sem", modifier = Modifier.weight(0.1f), fontWeight = FontWeight.Bold, color = Color.White)
        }

        // Data Tabel
        LazyColumn {
            items(mataKuliahList) { mataKuliah ->
                Row(
                    modifier = Modifier
                        .fillMaxWidth()
                        .padding(8.dp),
                    verticalAlignment = Alignment.CenterVertically
                ) {
                    Text(mataKuliah.no.toString(), modifier = Modifier.weight(0.1f))
                    Text(mataKuliah.namaMK, modifier = Modifier.weight(0.4f))
                    Text(mataKuliah.sem.toString(), modifier = Modifier.weight(0.1f))
                }
            }
        }
    }
}